==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/jabbersearch.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>JabberSearch</name>
    <message>
        <source>Jabber Search</source>
        <translation>Jabber Suche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>Email Address</source>
        <translation>E-Mail Adresse</translation>
    </message>
    <message>
        <source>Allows to search in the Jabber network</source>
        <translation>Erlaubt die Suche im Jabbernetzwerk</translation>
    </message>
    <message>
        <source>Supports the searching of the information</source>
        <translation>Unterstützt das Suchen der Information</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search in %1</source>
        <translation>Suche in %1</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Warte auf Host Antwort...</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Disco Info</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vKarte</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Geforderte Operation fehlgeschlagen: %1</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SearchDialogClass</name>
    <message>
        <source>First:</source>
        <translation>Vorname:</translation>
    </message>
    <message>
        <source>Last:</source>
        <translation>Nachname:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation>Spitzname:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>JID</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>First</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Last</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>EMail</source>
        <translation>E-mail</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/jabbersearch.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>JabberSearch</name>
    <message>
        <source>Jabber Search</source>
        <translation>Jabber Suche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>Email Address</source>
        <translation>E-Mail Adresse</translation>
    </message>
    <message>
        <source>Allows to search in the Jabber network</source>
        <translation>Erlaubt die Suche im Jabber-Netzwerk</translation>
    </message>
    <message>
        <source>Supports the searching of the information</source>
        <translation>Unterstützt das Suchen der Information</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search in %1</source>
        <translation>Suche in %1</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Warte auf Host Antwort...</translation>
    </message>
    <message>
        <source>Disco info</source>
        <translation>Disco Info</translation>
    </message>
    <message>
        <source>Add Contact</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>vCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Angeforderte Operation fehlgeschlagen: %1</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation>Fehler: Kann Anfrage nicht zum Host senden.</translation>
    </message>
</context>
<context>
    <name>SearchDialogClass</name>
    <message>
        <source>First:</source>
        <translation>Vorname:</translation>
    </message>
    <message>
        <source>Last:</source>
        <translation>Nachname:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation>Spitzname:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>JID</source>
        <translation>JID</translation>
    </message>
    <message>
        <source>First</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Last</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>EMail</source>
        <translation>E-Mail</translation>
    </message>
</context>
</TS>
